require 'crabbs/cli'
require 'webmock/rspec'

describe Crabbs::CLI do
  subject { Crabbs::CLI.new }

  describe '#start' do
    context 'with no arguments' do
      it 'prints out help' do
        ARGV.replace []

        allow(STDOUT).to receive(:puts)

        subject.start

        expect(STDOUT).to have_received(:puts).with('Missing required option(s): url')
      end
    end

    context 'with required arguments' do
      it 'outputs the result' do
        ARGV.replace ['--url=https://example.com']

        allow(Crabbs).to receive(:start).and_return('result')
        allow(STDOUT).to receive(:puts)

        subject.start

        expect(Crabbs).to have_received(:start).with({ url: 'https://example.com', verbose: false })
        expect(STDOUT).to have_received(:puts).with("\nResult:\n#{'result'.to_json}")
      end
    end

    context 'integration with crabbs' do
      before do
         stub_request(:get, "http://example.com/").to_return(:body => "")
      end

      it 'does not break contract' do
        ARGV.replace ['--url=http://example.com']
        allow(STDOUT).to receive(:puts)

        subject.start

        output = "\nResult:\n#{{ 'http://example.com' => {} }.to_json}"

        expect(STDOUT).to have_received(:puts).with(output)
      end
    end
  end
end
