require 'crabbs/page'

describe Crabbs::Page do
  describe '#links' do
    let(:host) { 'http://localhost.com/' }

    subject { Crabbs::Page.new(html, host) }

    context 'when html has external links' do
      let(:html) { %Q{<a href="http://facebook.com/"></a>} }

      it 'ignores external links' do
        subject.links.should be_empty
      end
    end

    context 'when html has links for non html resources' do
      let(:html) { %Q{<a href="http://localhost.com/path.zip"></a>} }

      it 'ignores non html links' do
        subject.links.should be_empty
      end

    end

    context 'when html has links for subdomains' do
      let(:html) { %Q{<a href="http://subdomain.localhost.com/path"></a>} }

      it 'ignores subdomain links' do
        subject.links.should be_empty
      end
    end

    context 'when html has query parameter links' do
      let(:html) { %Q{<a href="?path=1"></a><a href="?path=1"></a>} }

      it 'includes the full uri link' do
        subject.links.should == ['http://localhost.com/?path=1']
      end
    end

    context 'when html has hash links' do
      let(:html) { %Q{<a href="#path"></a><a href="#path"></a><a href="#"></a>} }

      it 'includes the full uri link' do
        subject.links.should == ['http://localhost.com/#path']
      end

      it 'ignore empty hashes' do
        subject.links.should_not include('http://localhost.com/#')
      end
    end

    context 'when html has direct path links' do
      let(:host) { 'http://localhost.com/first/' }
      let(:html) { %Q{<a href="path"></a><a href="path"></a>} }

      it 'includes the full uri link' do
        subject.links.should == ['http://localhost.com/first/path']
      end
    end

    context 'when html has path links' do
      let(:html) { %Q{<a href="/path"></a><a href="/path"></a>} }

      it 'includes the full uri link' do
        subject.links.should == ['http://localhost.com/path']
      end
    end

    context 'when html has full URI links for the same host' do
      let(:html) { %Q{<a href="http://localhost.com/path"></a><a href="/path"></a>} }

      it 'includes the full uri link' do
        subject.links.should == ['http://localhost.com/path']
      end
    end
  end
end
